function s = fmtdetections(detections, indices)
% s = fmtdetections(detections, indices)
% Create a string with formmatted detection(s) as specified
% by indices
%
% detections must be in the format returned by read_annotations.
%
% e.g. fmtdetections(detections, [1:2:length(detections.starts))]
% would show odd numbered detections.
%
% If indices is ommitted, all detections are shown

narginchk(1,2);

if nargin < 2
    indices = 1:length(detections.start);
end

s = cell(length(indices),1);

callP = isfield(detections, 'call');
callstr = '';
for m = 1:length(indices)
    idx = indices(m);
    % format each entry
    if (callP)
        callstr = detections.call{idx};
    end
    s{m} = sprintf('%s - %s: %s %s %s %s', ...
        dbSerialDateToISO8601(detections.start(idx)), ...
        dbSerialDateToISO8601(detections.end(idx)), ...
        detections.project{idx}, ...
        detections.site{idx}, ...
        detections.species{idx}, ...
        callstr);    
end

% Concatentate
s = strjoin(s', '\n');