function intervals = merge(intervals)
% merged = merge(intervals)
% Given an Nx2 matrix of start and end time units, 
% produce a new list that contains non overlapping segments.
% Assumes matrix is sorted by start time.
%
% Example:
%  5 rows with start and ends representing the following times:
%  --------------------------
%       ------------
%            --------------------
%                                          -------------
%                                                    ------------
%  Time axis --->
% Returns
%  2 rows with non-overlapping times
%  -------------------------------
%                                          ----------------------

rows = size(intervals, 1);
ridx = rows;
while ridx > 1
    % Any rows that end after the start time of this one overlap
    % as their start must be *before* the current index.
    overlaps = find(intervals(1:ridx-1, 2) > intervals(ridx, 1));
    if ~ isempty(overlaps)
        % Merge the overlaps
        [~, earliestidx] = min(intervals(overlaps, 1));
        % new earliest date
        intervals(ridx, 1) = intervals(overlaps(earliestidx), 1);
        % earlier ranges may extend past the current one
        intervals(ridx, 2) = max(intervals(ridx, 2), ...
            max(intervals(overlaps,2)));
        % Remove overlapped areas
        intervals(overlaps(earliestidx):ridx-1, :) = [];
        ridx = ridx - (ridx - overlaps(earliestidx));
    else
        ridx = ridx - 1;  % no overlap, check next
    end
end
